@@ -4,18 +4,25 @@ from swap.common.config import Settings
 
 client = UBLClient()
 
-
 class Dataset:
-    def __init__(self, input_dataset):
+    def __init__(self, input_dataset, metadata=""):
         self.name = input_dataset.name
         self.input_dataset = input_dataset
         self.dataset_type = 'GCS'
         self.url = f'gs://{Settings.BUCKET}/{input_dataset.name}'
+        self.metadata = metadata
+
+    def to_dict(self):
+        dataset_dict = {}
+        dataset_dict['url'] = self.url
+        dataset_dict['name'] = self.name
+        dataset_dict['metadata'] = self.metadata
+        return dataset_dict
 
 
 class CDFDataset:
-    def __init__(self, dataset_id, survey_id = "N/A"):
-        if survey_id is not "N/A":
+    def __init__(self, dataset_id, survey_id="N/A", metadata=""):
+        if survey_id != "N/A":
             self.url = f'cdf://{survey_id}/{dataset_id}'
         else:
             self.url = f'cdf://{dataset_id}'
@@ -23,6 +30,14 @@ class CDFDataset:
         self.survey_id = survey_id
         self.dataset_id = dataset_id
         self.dataset_type = 'CDF'
+        self.metadata = metadata
+
+    def to_dict(self):
+        dataset_dict = {}
+        dataset_dict['url'] = self.url
+        dataset_dict['name'] = self.name
+        dataset_dict['metadata'] = self.metadata
+        return dataset_dict
 
 
 def list_all():
