@@ -285,7 +285,7 @@ class InputDatasetsResponseSchema(Schema):
 
 class ServiceRequestChainLinkSchema(Schema):
     service = fields.Str()
-    datasets = fields.List(fields.Str())
+    datasets = fields.List(fields.Dict())
 
     @post_load
     def deserialise(self, other, **kwargs):
